crikit.datasets package
=======================

Submodules
----------

crikit.datasets.model module
----------------------------

.. automodule:: crikit.datasets.model
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: crikit.datasets
   :members:
   :undoc-members:
   :show-inheritance:
